@@ -1,4 +1,4 @@
-# Copyright (C) 2011-2012 by Barry A. Warsaw
+# Copyright (C) 2011-2014 by Barry A. Warsaw
 #
 # This file is part of flufl.password
 #
@@ -20,6 +20,13 @@ from __future__ import absolute_import, print_function, unicode_literals
 
 __metaclass__ = type
 __all__ = [
+    'TestCleartextPasswords',
+    'TestNoPasswords',
+    'TestPBKDF2Passwords',
+    'TestPasswordGeneration',
+    'TestSHAPasswords',
+    'TestSSHAPasswords',
+    'TestSchemeLookup',
     ]
 
 
